;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "alt-codes" "20250101.1002"
  "Insert alt codes using meta key."
  '((emacs "26.1"))
  :url "https://github.com/jcs-elpa/alt-codes"
  :commit "24e3740f88c29efda5c4791720a55c4c548b1ed8"
  :revdesc "24e3740f88c2"
  :keywords '("convenience" "alt" "codes" "insertion" "meta")
  :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
  :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
